AffinityFilter

Struct AffinityFilter 

pub struct AffinityFilter { /* private fields */ }

Implementations

Source

impl AffinityFilter

pub fn new(seed: u128, false_pos: f64, expected_items: usize) -> AffinityFilter

pub fn from_topics<'a>( topics: impl Iterator<Item = &'a [u8; 32]>, seed: u128, false_positive_rate: f64, ) -> AffinityFilter

pub fn decode(data: &[u8]) -> Result<AffinityFilter, DecodeAffinityFilterError>

pub fn insert(&mut self, topic: &[u8; 32])

Insert a topic into the bloom filter.

pub fn contains(&self, topic: &[u8; 32]) -> bool

Check if a topic is likely present in the bloom filter.

pub fn matches_statement(&self, topics: &[&[u8; 32]]) -> bool

Check if topics match this affinity filter.

Topics match if any of them is present in the bloom filter. No topics always match (from broadcast statements).

pub fn encode_to_vec(&self) -> Vec<u8>

pub fn match_all(seed: u128) -> AffinityFilter